﻿using System;
using System.Collections.Generic;
using System.Data;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace ConsoleApp1
{
	class Program
	{
		private static DataTable _Data;

		static void Main(string[] args)
		{
			CreateData();

			//-- Create a query straight from the data table and implement your WHERE logic
			var query = from _Data in _Data.AsEnumerable()
						where _Data.Field<string>("Last").Equals("smith", StringComparison.OrdinalIgnoreCase)
						select new
						{
							First = _Data.Field<string>("First"),
							Last = _Data.Field<string>("Last"),
							Dob = _Data.Field<DateTime>("Dob")
						};

			//-- Now you can enumerate the query
			foreach(var i in query)
			{
				Console.WriteLine($"First: {i.First} Last: {i.Last} Date of Birth: {i.Dob.ToString("MM/dd/yyyy")}");
			}

			Console.WriteLine("");
			Console.WriteLine("Now filter out using inline LINQ instead of the query");
			Console.WriteLine("");

			//-- You can also leave the WHERE out of the query itself and then use LINQ to filter out the list.
			//   This is my preferred approach in a situation like this.
			foreach(var i in query.Where(i => i.Dob == new DateTime(1952,01,01)))
			{
				Console.WriteLine($"First: {i.First} Last: {i.Last} Date of Birth: {i.Dob.ToString("MM/dd/yyyy")}");
			}


			Console.ReadKey();
		}

		private static void CreateData()
		{
			//-- Create a data table for testing
			_Data = new DataTable("Testing");
			_Data.Columns.Add("First", typeof(string));
			_Data.Columns.Add("Last", typeof(string));
			_Data.Columns.Add("Dob", typeof(DateTime));

			//-- Create some records
			var row = _Data.NewRow();
			row["First"] = "John";
			row["Last"] = "Smith";
			row["Dob"] = new DateTime(1952,01,01);
			_Data.Rows.Add(row);

			row = _Data.NewRow();
			row["First"] = "Neta";
			row["Last"] = "Aberdeen";
			row["Dob"] = new DateTime(1948, 10, 12);
			_Data.Rows.Add(row);

			row = _Data.NewRow();
			row["First"] = "Able";
			row["Last"] = "Smith";
			row["Dob"] = new DateTime(1968, 06, 05);
			_Data.Rows.Add(row);

			row = _Data.NewRow();
			row["First"] = "Jed";
			row["Last"] = "Lazbuddie";
			row["Dob"] = new DateTime(1970, 12, 09);
			_Data.Rows.Add(row);
		}
	}
}
